@@ -14,11 +14,11 @@ Map::Tube - A very simple perl interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 =head1 SYNOPSIS
@@ -68,9 +68,9 @@ takes into account the number of stops one has to go through to reach the destin
 do agree, at times, you wouldn't mind going through few extra stops, to avoid changing 
 lines. I might add this behaviour in future. Please note Map::Tube doesn't try to 
 explain Dijkstra's algorithm but to provide a perl interface to the London Tube Map.
-As of today, it covers only Bakerloo, Central, Circle, District, Hammersmith & City, 
-Jubilee and Victoria. I have been working hard to cover all the remaining (Metropolitan, 
-Northern, Picadilly and Waterloo & City). Here is the link to the official London Tube Map:
+As of today, it covers Bakerloo, Central, Circle, District, Hammersmith & City, Jubilee, 
+Metropolitan and Victoria. I have been working hard to cover all the remaining 
+(Northern, Picadilly and Waterloo & City). Here is the link to the official London Tube Map:
 http://www.tfl.gov.uk/assets/downloads/standard-tube-map.pdf
 
 =cut
